@@ -11,13 +11,15 @@ function remove_from_path {
     echo "$RESULT"
 }
 
-NEW_PATH=remove_from_path "${DOTNET_ROOT}"
-NEW_PATH=remove_from_path "${DOTNET_TOOLS}" "${NEW_PATH}"
+NEW_PATH=$(remove_from_path "${DOTNET_ROOT}")
+NEW_PATH=$(remove_from_path "${DOTNET_TOOLS}" "${NEW_PATH}")
 export PATH=$NEW_PATH
 
 unset DOTNET_CLI_TELEMETRY_OPTOUT
 unset DOTNET_SKIP_FIRST_TIME_EXPERIENCE
 unset DOTNET_ADD_GLOBAL_TOOLS_TO_PATH
+unset DOTNET_MULTILEVEL_LOOKUP
 
 export DOTNET_ROOT=_CONDA_BACKUP_DOTNET_ROOT
 export DOTNET_TOOLS=_CONDA_BACKUP_DOTNET_TOOLS
+export LD_LIBRARY_PATH=_CONDA_BACKUP_LD_LIBRARY_PATH
